from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Interface import *
from OCC.Core.TCollection import *
from OCC.Core.TColStd import *
from OCC.Core.Resource import *


class StepData_Array1OfField:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepData_Field: ...
    def __setitem__(self, index: int, value: StepData_Field) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepData_Field]: ...
    def next(self) -> StepData_Field: ...
    __next__ = next
    def Init(self, theValue: StepData_Field) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepData_Field: ...
    def Last(self) -> StepData_Field: ...
    def Value(self, theIndex: int) -> StepData_Field: ...
    def SetValue(self, theIndex: int, theValue: StepData_Field) -> None: ...

class StepData_Logical(IntEnum):
	StepData_LFalse: int = ...
	StepData_LTrue: int = ...
	StepData_LUnknown: int = ...
StepData_LFalse = StepData_Logical.StepData_LFalse
StepData_LTrue = StepData_Logical.StepData_LTrue
StepData_LUnknown = StepData_Logical.StepData_LUnknown

class stepdata:
	@staticmethod
	def AddHeaderProtocol(headerproto: StepData_Protocol) -> None: ...
	@staticmethod
	def HeaderProtocol() -> StepData_Protocol: ...
	@staticmethod
	def Init() -> None: ...
	@staticmethod
	def Protocol() -> StepData_Protocol: ...

class StepData_Described(Standard_Transient):
	def As(self, steptype: str) -> StepData_Simple: ...
	def CField(self, name: str) -> StepData_Field: ...
	def Check(self, ach: Interface_Check) -> None: ...
	def Description(self) -> StepData_EDescr: ...
	def Field(self, name: str) -> StepData_Field: ...
	def HasField(self, name: str) -> bool: ...
	def IsComplex(self) -> bool: ...
	def Matches(self, steptype: str) -> bool: ...
	def Shared(self, list: Interface_EntityIterator) -> None: ...

class StepData_EDescr(Standard_Transient):
	def IsComplex(self) -> bool: ...
	def Matches(self, steptype: str) -> bool: ...
	def NewEntity(self) -> StepData_Described: ...

class StepData_EnumTool:
	def __init__(self, e0: Optional[str] = "", e1: Optional[str] = "", e2: Optional[str] = "", e3: Optional[str] = "", e4: Optional[str] = "", e5: Optional[str] = "", e6: Optional[str] = "", e7: Optional[str] = "", e8: Optional[str] = "", e9: Optional[str] = "", e10: Optional[str] = "", e11: Optional[str] = "", e12: Optional[str] = "", e13: Optional[str] = "", e14: Optional[str] = "", e15: Optional[str] = "", e16: Optional[str] = "", e17: Optional[str] = "", e18: Optional[str] = "", e19: Optional[str] = "", e20: Optional[str] = "", e21: Optional[str] = "", e22: Optional[str] = "", e23: Optional[str] = "", e24: Optional[str] = "", e25: Optional[str] = "", e26: Optional[str] = "", e27: Optional[str] = "", e28: Optional[str] = "", e29: Optional[str] = "", e30: Optional[str] = "", e31: Optional[str] = "", e32: Optional[str] = "", e33: Optional[str] = "", e34: Optional[str] = "", e35: Optional[str] = "", e36: Optional[str] = "", e37: Optional[str] = "", e38: Optional[str] = "", e39: Optional[str] = "") -> None: ...
	def AddDefinition(self, term: str) -> None: ...
	def IsSet(self) -> bool: ...
	def MaxValue(self) -> int: ...
	def NullValue(self) -> int: ...
	def Optional(self, mode: bool) -> None: ...
	def Text(self, num: int) -> TCollection_AsciiString: ...
	@overload
	def Value(self, txt: str) -> int: ...
	@overload
	def Value(self, txt: TCollection_AsciiString) -> int: ...

class StepData_Field:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, other: StepData_Field, copy: Optional[bool] = False) -> None: ...
	def Arity(self) -> int: ...
	def Boolean(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> bool: ...
	def Clear(self, kind: Optional[int] = 0) -> None: ...
	def ClearItem(self, num: int) -> None: ...
	def CopyFrom(self, other: StepData_Field) -> None: ...
	def Entity(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> Standard_Transient: ...
	def Enum(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> int: ...
	def EnumText(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> str: ...
	def Int(self) -> int: ...
	def Integer(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> int: ...
	def IsSet(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> bool: ...
	def ItemKind(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> int: ...
	def Kind(self, type: Optional[bool] = True) -> int: ...
	def Length(self, index: Optional[int] = 1) -> int: ...
	def Logical(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> StepData_Logical: ...
	def Lower(self, index: Optional[int] = 1) -> int: ...
	def Real(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> float: ...
	def Set(self, val: Standard_Transient) -> None: ...
	@overload
	def SetBoolean(self, val: Optional[bool] = False) -> None: ...
	@overload
	def SetBoolean(self, num: int, val: bool) -> None: ...
	def SetDerived(self) -> None: ...
	@overload
	def SetEntity(self, val: Standard_Transient) -> None: ...
	@overload
	def SetEntity(self) -> None: ...
	@overload
	def SetEntity(self, num: int, val: Standard_Transient) -> None: ...
	@overload
	def SetEnum(self, val: Optional[int] = -1, text: Optional[str] = "") -> None: ...
	@overload
	def SetEnum(self, num: int, val: int, text: Optional[str] = "") -> None: ...
	@overload
	def SetInt(self, val: int) -> None: ...
	@overload
	def SetInt(self, num: int, val: int, kind: int) -> None: ...
	@overload
	def SetInteger(self, val: Optional[int] = 0) -> None: ...
	@overload
	def SetInteger(self, num: int, val: int) -> None: ...
	def SetList(self, size: int, first: Optional[int] = 1) -> None: ...
	def SetList2(self, siz1: int, siz2: int, f1: Optional[int] = 1, f2: Optional[int] = 1) -> None: ...
	@overload
	def SetLogical(self, val: Optional[StepData_Logical] = StepData_LFalse) -> None: ...
	@overload
	def SetLogical(self, num: int, val: StepData_Logical) -> None: ...
	@overload
	def SetReal(self, val: Optional[float] = 0.0) -> None: ...
	@overload
	def SetReal(self, num: int, val: float) -> None: ...
	def SetSelectMember(self, val: StepData_SelectMember) -> None: ...
	@overload
	def SetString(self, val: Optional[str] = "") -> None: ...
	@overload
	def SetString(self, num: int, val: str) -> None: ...
	def String(self, n1: Optional[int] = 1, n2: Optional[int] = 1) -> str: ...
	def Transient(self) -> Standard_Transient: ...

class StepData_FieldList:
	def __init__(self) -> None: ...
	def CField(self, num: int) -> StepData_Field: ...
	def Field(self, num: int) -> StepData_Field: ...
	def FillShared(self, iter: Interface_EntityIterator) -> None: ...
	def NbFields(self) -> int: ...

class StepData_FileRecognizer(Standard_Transient):
	def Add(self, reco: StepData_FileRecognizer) -> None: ...
	def Evaluate(self, akey: TCollection_AsciiString, res: Standard_Transient) -> bool: ...
	def Result(self) -> Standard_Transient: ...

class StepData_GeneralModule(Interface_GeneralModule):
	def CheckCase(self, casenum: int, ent: Standard_Transient, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def CopyCase(self, casenum: int, entfrom: Standard_Transient, entto: Standard_Transient, TC: Interface_CopyTool) -> None: ...
	def FillSharedCase(self, casenum: int, ent: Standard_Transient, iter: Interface_EntityIterator) -> None: ...

class StepData_GlobalNodeOfWriterLib(Standard_Transient):
	def __init__(self) -> None: ...
	def Add(self, amodule: StepData_ReadWriteModule, aprotocol: StepData_Protocol) -> None: ...
	def Module(self) -> StepData_ReadWriteModule: ...
	def Next(self) -> StepData_GlobalNodeOfWriterLib: ...
	def Protocol(self) -> StepData_Protocol: ...

class StepData_NodeOfWriterLib(Standard_Transient):
	def __init__(self) -> None: ...
	def AddNode(self, anode: StepData_GlobalNodeOfWriterLib) -> None: ...
	def Module(self) -> StepData_ReadWriteModule: ...
	def Next(self) -> StepData_NodeOfWriterLib: ...
	def Protocol(self) -> StepData_Protocol: ...

class StepData_PDescr(Standard_Transient):
	def __init__(self) -> None: ...
	def AddArity(self, arity: Optional[int] = 1) -> None: ...
	def AddEnumDef(self, enumdef: str) -> None: ...
	def AddMember(self, member: StepData_PDescr) -> None: ...
	def Arity(self) -> int: ...
	def Check(self, afild: StepData_Field, ach: Interface_Check) -> None: ...
	def DescrName(self) -> str: ...
	def EnumMax(self) -> int: ...
	def EnumText(self, val: int) -> str: ...
	def EnumValue(self, name: str) -> int: ...
	def FieldName(self) -> str: ...
	def FieldRank(self) -> int: ...
	def IsBoolean(self) -> bool: ...
	def IsDerived(self) -> bool: ...
	def IsDescr(self, descr: StepData_EDescr) -> bool: ...
	def IsEntity(self) -> bool: ...
	def IsEnum(self) -> bool: ...
	def IsField(self) -> bool: ...
	def IsInteger(self) -> bool: ...
	def IsLogical(self) -> bool: ...
	def IsOptional(self) -> bool: ...
	def IsReal(self) -> bool: ...
	def IsSelect(self) -> bool: ...
	def IsString(self) -> bool: ...
	def IsType(self, atype: Standard_Type) -> bool: ...
	def Member(self, name: str) -> StepData_PDescr: ...
	def Name(self) -> str: ...
	def SetArity(self, arity: Optional[int] = 1) -> None: ...
	def SetBoolean(self) -> None: ...
	def SetDerived(self, der: Optional[bool] = True) -> None: ...
	def SetDescr(self, dscnam: str) -> None: ...
	def SetEnum(self) -> None: ...
	def SetField(self, name: str, rank: int) -> None: ...
	def SetFrom(self, other: StepData_PDescr) -> None: ...
	def SetInteger(self) -> None: ...
	def SetLogical(self) -> None: ...
	def SetMemberName(self, memname: str) -> None: ...
	def SetName(self, name: str) -> None: ...
	def SetOptional(self, opt: Optional[bool] = True) -> None: ...
	def SetReal(self) -> None: ...
	def SetSelect(self) -> None: ...
	def SetString(self) -> None: ...
	def SetType(self, atype: Standard_Type) -> None: ...
	def Simple(self) -> StepData_PDescr: ...
	def Type(self) -> Standard_Type: ...

class StepData_Protocol(Interface_Protocol):
	def __init__(self) -> None: ...
	def AddBasicDescr(self, esdescr: StepData_ESDescr) -> None: ...
	def AddDescr(self, adescr: StepData_EDescr, CN: int) -> None: ...
	def AddPDescr(self, pdescr: StepData_PDescr) -> None: ...
	def BasicDescr(self, name: str, anylevel: Optional[bool] = True) -> StepData_EDescr: ...
	def CaseNumber(self, obj: Standard_Transient) -> int: ...
	@overload
	def Descr(self, num: int) -> StepData_EDescr: ...
	@overload
	def Descr(self, name: str, anylevel: Optional[bool] = True) -> StepData_EDescr: ...
	def DescrNumber(self, adescr: StepData_EDescr) -> int: ...
	def ECDescr(self, names: TColStd_SequenceOfAsciiString, anylevel: Optional[bool] = True) -> StepData_ECDescr: ...
	def ESDescr(self, name: str, anylevel: Optional[bool] = True) -> StepData_ESDescr: ...
	def HasDescr(self) -> bool: ...
	def IsSuitableModel(self, model: Interface_InterfaceModel) -> bool: ...
	def IsUnknownEntity(self, ent: Standard_Transient) -> bool: ...
	def NbResources(self) -> int: ...
	def NewModel(self) -> Interface_InterfaceModel: ...
	def PDescr(self, name: str, anylevel: Optional[bool] = True) -> StepData_PDescr: ...
	def Resource(self, num: int) -> Interface_Protocol: ...
	def SchemaName(self) -> str: ...
	def TypeNumber(self, atype: Standard_Type) -> int: ...
	def UnknownEntity(self) -> Standard_Transient: ...

class StepData_ReadWriteModule(Interface_ReaderModule):
	def CaseNum(self, data: Interface_FileReaderData, num: int) -> int: ...
	@overload
	def CaseStep(self, atype: TCollection_AsciiString) -> int: ...
	@overload
	def CaseStep(self, types: TColStd_SequenceOfAsciiString) -> int: ...
	def ComplexType(self, CN: int, types: TColStd_SequenceOfAsciiString) -> bool: ...
	def IsComplex(self, CN: int) -> bool: ...
	def Read(self, CN: int, data: Interface_FileReaderData, num: int, ach: Interface_Check, ent: Standard_Transient) -> None: ...
	def ReadStep(self, CN: int, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: Standard_Transient) -> None: ...
	def ShortType(self, CN: int) -> TCollection_AsciiString: ...
	def StepType(self, CN: int) -> TCollection_AsciiString: ...
	def WriteStep(self, CN: int, SW: StepData_StepWriter, ent: Standard_Transient) -> None: ...

class StepData_SelectMember(Standard_Transient):
	def __init__(self) -> None: ...
	def Boolean(self) -> bool: ...
	def Enum(self) -> int: ...
	def EnumText(self) -> str: ...
	def HasName(self) -> bool: ...
	def Int(self) -> int: ...
	def Integer(self) -> int: ...
	def Kind(self) -> int: ...
	def Logical(self) -> StepData_Logical: ...
	def Matches(self, name: str) -> bool: ...
	def Name(self) -> str: ...
	def ParamType(self) -> Interface_ParamType: ...
	def Real(self) -> float: ...
	def SetBoolean(self, val: bool) -> None: ...
	def SetEnum(self, val: int, text: Optional[str] = "") -> None: ...
	def SetEnumText(self, val: int, text: str) -> None: ...
	def SetInt(self, val: int) -> None: ...
	def SetInteger(self, val: int) -> None: ...
	def SetKind(self, kind: int) -> None: ...
	def SetLogical(self, val: StepData_Logical) -> None: ...
	def SetName(self, name: str) -> bool: ...
	def SetReal(self, val: float) -> None: ...
	def SetString(self, val: str) -> None: ...
	def String(self) -> str: ...

class StepData_SelectType:
	def Boolean(self) -> bool: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseMember(self) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def CaseNumber(self) -> int: ...
	def Description(self) -> StepData_PDescr: ...
	def Int(self) -> int: ...
	def Integer(self) -> int: ...
	def IsNull(self) -> bool: ...
	def Logical(self) -> StepData_Logical: ...
	def Matches(self, ent: Standard_Transient) -> bool: ...
	def Member(self) -> StepData_SelectMember: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def Nullify(self) -> None: ...
	def Real(self) -> float: ...
	def SelectName(self) -> str: ...
	def SetBoolean(self, val: bool, name: Optional[str] = "") -> None: ...
	def SetInt(self, val: int) -> None: ...
	def SetInteger(self, val: int, name: Optional[str] = "") -> None: ...
	def SetLogical(self, val: StepData_Logical, name: Optional[str] = "") -> None: ...
	def SetReal(self, val: float, name: Optional[str] = "") -> None: ...
	def SetValue(self, ent: Standard_Transient) -> None: ...
	def Type(self) -> Standard_Type: ...
	def Value(self) -> Standard_Transient: ...

class StepData_StepDumper:
	def __init__(self, amodel: StepData_StepModel, protocol: StepData_Protocol, mode: Optional[int] = 0) -> None: ...
	def StepWriter(self) -> StepData_StepWriter: ...

class StepData_StepModel(Interface_InterfaceModel):
	def __init__(self) -> None: ...
	def AddHeaderEntity(self, ent: Standard_Transient) -> None: ...
	def ClearHeader(self) -> None: ...
	def ClearLabels(self) -> None: ...
	def Entity(self, num: int) -> Standard_Transient: ...
	def GetFromAnother(self, other: Interface_InterfaceModel) -> None: ...
	def HasHeaderEntity(self, atype: Standard_Type) -> bool: ...
	def Header(self) -> Interface_EntityIterator: ...
	def HeaderEntity(self, atype: Standard_Type) -> Standard_Transient: ...
	def IdentLabel(self, ent: Standard_Transient) -> int: ...
	def NewEmptyModel(self) -> Interface_InterfaceModel: ...
	def SetIdentLabel(self, ent: Standard_Transient, ident: int) -> None: ...
	def SetSourceCodePage(self, theCode: Resource_FormatType) -> None: ...
	def SourceCodePage(self) -> Resource_FormatType: ...
	def StringLabel(self, ent: Standard_Transient) -> TCollection_HAsciiString: ...
	def VerifyCheck(self, ach: Interface_Check) -> None: ...

class StepData_StepReaderData(Interface_FileReaderData):
	def __init__(self, nbheader: int, nbtotal: int, nbpar: int, theSourceCodePage: Optional[Resource_FormatType] = Resource_FormatType_UTF8) -> None: ...
	def AddStepParam(self, num: int, aval: str, atype: Interface_ParamType, nument: Optional[int] = 0) -> None: ...
	def CType(self, num: int) -> str: ...
	def CheckDerived(self, num: int, nump: int, mess: str, ach: Interface_Check, errstat: Optional[bool] = False) -> bool: ...
	def CheckNbParams(self, num: int, nbreq: int, ach: Interface_Check, mess: Optional[str] = "") -> bool: ...
	def ComplexType(self, num: int, types: TColStd_SequenceOfAsciiString) -> None: ...
	def FailEnumValue(self, num: int, nump: int, mess: str, ach: Interface_Check) -> None: ...
	def FindNextHeaderRecord(self, num: int) -> int: ...
	def FindNextRecord(self, num: int) -> int: ...
	def GlobalCheck(self) -> Interface_Check: ...
	def IsComplex(self, num: int) -> bool: ...
	@overload
	def NamedForComplex(self, name: str, num0: int, ach: Interface_Check) -> Tuple[bool, int]: ...
	@overload
	def NamedForComplex(self, theName: str, theShortName: str, num0: int, ach: Interface_Check) -> Tuple[bool, int]: ...
	def NbEntities(self) -> int: ...
	def NextForComplex(self, num: int) -> int: ...
	def PrepareHeader(self) -> None: ...
	def ReadAny(self, num: int, nump: int, mess: str, ach: Interface_Check, descr: StepData_PDescr, val: Standard_Transient) -> bool: ...
	def ReadBoolean(self, num: int, nump: int, mess: str, ach: Interface_Check) -> Tuple[bool, bool]: ...
	def ReadEnum(self, num: int, nump: int, mess: str, ach: Interface_Check, enumtool: StepData_EnumTool) -> Tuple[bool, int]: ...
	def ReadEnumParam(self, num: int, nump: int, mess: str, ach: Interface_Check, text: str) -> bool: ...
	def ReadField(self, num: int, nump: int, mess: str, ach: Interface_Check, descr: StepData_PDescr, fild: StepData_Field) -> bool: ...
	def ReadInteger(self, num: int, nump: int, mess: str, ach: Interface_Check) -> Tuple[bool, int]: ...
	def ReadList(self, num: int, ach: Interface_Check, descr: StepData_ESDescr, list: StepData_FieldList) -> bool: ...
	def ReadLogical(self, num: int, nump: int, mess: str, ach: Interface_Check, flag: StepData_Logical) -> bool: ...
	def ReadReal(self, num: int, nump: int, mess: str, ach: Interface_Check) -> Tuple[bool, float]: ...
	def ReadString(self, num: int, nump: int, mess: str, ach: Interface_Check, val: TCollection_HAsciiString) -> bool: ...
	def ReadSub(self, numsub: int, mess: str, ach: Interface_Check, descr: StepData_PDescr, val: Standard_Transient) -> int: ...
	def ReadSubList(self, num: int, nump: int, mess: str, ach: Interface_Check, optional: Optional[bool] = False, lenmin: Optional[int] = 0, lenmax: Optional[int] = 0) -> Tuple[bool, int]: ...
	def ReadTypedParam(self, num: int, nump: int, mustbetyped: bool, mess: str, ach: Interface_Check, typ: TCollection_AsciiString) -> Tuple[bool, int, int]: ...
	def ReadXY(self, num: int, nump: int, mess: str, ach: Interface_Check) -> Tuple[bool, float, float]: ...
	def ReadXYZ(self, num: int, nump: int, mess: str, ach: Interface_Check) -> Tuple[bool, float, float, float]: ...
	def RecordIdent(self, num: int) -> int: ...
	def RecordType(self, num: int) -> TCollection_AsciiString: ...
	def SetEntityNumbers(self, withmap: Optional[bool] = True) -> None: ...
	def SetRecord(self, num: int, ident: str, type: str, nbpar: int) -> None: ...
	def SubListNumber(self, num: int, nump: int, aslast: bool) -> int: ...

class StepData_StepReaderTool(Interface_FileReaderTool):
	def __init__(self, reader: StepData_StepReaderData, protocol: StepData_Protocol) -> None: ...
	def AnalyseRecord(self, num: int, anent: Standard_Transient, acheck: Interface_Check) -> bool: ...
	def BeginRead(self, amodel: Interface_InterfaceModel) -> None: ...
	def EndRead(self, amodel: Interface_InterfaceModel) -> None: ...
	@overload
	def Prepare(self, optimize: Optional[bool] = True) -> None: ...
	@overload
	def Prepare(self, reco: StepData_FileRecognizer, optimize: Optional[bool] = True) -> None: ...
	def PrepareHeader(self, reco: StepData_FileRecognizer) -> None: ...
	def Recognize(self, num: int, ach: Interface_Check, ent: Standard_Transient) -> bool: ...

class StepData_StepWriter:
	def __init__(self, amodel: StepData_StepModel) -> None: ...
	def AddParam(self) -> None: ...
	def CheckList(self) -> Interface_CheckIterator: ...
	def CloseSub(self) -> None: ...
	def Comment(self, mode: bool) -> None: ...
	def EndComplex(self) -> None: ...
	def EndEntity(self) -> None: ...
	def EndFile(self) -> None: ...
	def EndSec(self) -> None: ...
	def FloatWriter(self) -> Interface_FloatWriter: ...
	def Indent(self, onent: bool) -> None: ...
	def IsInScope(self, num: int) -> bool: ...
	def JoinLast(self, newline: bool) -> None: ...
	def GetLabelMode(self) -> int: ...
	def SetLabelMode(self, value: int) -> None: ...
	def Line(self, num: int) -> TCollection_HAsciiString: ...
	def NbLines(self) -> int: ...
	def NewLine(self, evenempty: bool) -> None: ...
	def OpenSub(self) -> None: ...
	def OpenTypedSub(self, subtype: str) -> None: ...
	@overload
	def Send(self, val: int) -> None: ...
	@overload
	def Send(self, val: float) -> None: ...
	@overload
	def Send(self, val: TCollection_AsciiString) -> None: ...
	@overload
	def Send(self, val: Standard_Transient) -> None: ...
	def SendArrReal(self, anArr: TColStd_HArray1OfReal) -> None: ...
	def SendBoolean(self, val: bool) -> None: ...
	@overload
	def SendComment(self, text: TCollection_HAsciiString) -> None: ...
	@overload
	def SendComment(self, text: str) -> None: ...
	def SendData(self) -> None: ...
	def SendDerived(self) -> None: ...
	def SendEndscope(self) -> None: ...
	def SendEntity(self, nument: int, lib: StepData_WriterLib) -> None: ...
	@overload
	def SendEnum(self, val: TCollection_AsciiString) -> None: ...
	@overload
	def SendEnum(self, val: str) -> None: ...
	def SendField(self, fild: StepData_Field, descr: StepData_PDescr) -> None: ...
	def SendHeader(self) -> None: ...
	def SendIdent(self, ident: int) -> None: ...
	def SendList(self, list: StepData_FieldList, descr: StepData_ESDescr) -> None: ...
	def SendLogical(self, val: StepData_Logical) -> None: ...
	def SendModel(self, protocol: StepData_Protocol, headeronly: Optional[bool] = False) -> None: ...
	def SendScope(self) -> None: ...
	def SendSelect(self, sm: StepData_SelectMember, descr: StepData_PDescr) -> None: ...
	@overload
	def SendString(self, val: TCollection_AsciiString) -> None: ...
	@overload
	def SendString(self, val: str) -> None: ...
	def SendUndef(self) -> None: ...
	def SetScope(self, numscope: int, numin: int) -> None: ...
	def StartComplex(self) -> None: ...
	def StartEntity(self, atype: TCollection_AsciiString) -> None: ...
	def GetTypeMode(self) -> int: ...
	def SetTypeMode(self, value: int) -> None: ...

class StepData_WriterLib:
	@overload
	def __init__(self, aprotocol: StepData_Protocol) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def AddProtocol(self, aprotocol: Standard_Transient) -> None: ...
	def Clear(self) -> None: ...
	def Module(self) -> StepData_ReadWriteModule: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Protocol(self) -> StepData_Protocol: ...
	def Select(self, obj: Standard_Transient, module: StepData_ReadWriteModule) -> Tuple[bool, int]: ...
	def SetComplete(self) -> None: ...
	@staticmethod
	def SetGlobal(amodule: StepData_ReadWriteModule, aprotocol: StepData_Protocol) -> None: ...
	def Start(self) -> None: ...

class StepData_DefaultGeneral(StepData_GeneralModule):
	def __init__(self) -> None: ...
	def CheckCase(self, casenum: int, ent: Standard_Transient, shares: Interface_ShareTool, ach: Interface_Check) -> None: ...
	def CopyCase(self, casenum: int, entfrom: Standard_Transient, entto: Standard_Transient, TC: Interface_CopyTool) -> None: ...
	def FillSharedCase(self, casenum: int, ent: Standard_Transient, iter: Interface_EntityIterator) -> None: ...
	def NewVoid(self, CN: int, entto: Standard_Transient) -> bool: ...

class StepData_ECDescr(StepData_EDescr):
	def __init__(self) -> None: ...
	def Add(self, member: StepData_ESDescr) -> None: ...
	def IsComplex(self) -> bool: ...
	def Matches(self, steptype: str) -> bool: ...
	def Member(self, num: int) -> StepData_ESDescr: ...
	def NbMembers(self) -> int: ...
	def NewEntity(self) -> StepData_Described: ...
	def TypeList(self) -> TColStd_HSequenceOfAsciiString: ...

class StepData_ESDescr(StepData_EDescr):
	def __init__(self, name: str) -> None: ...
	def Base(self) -> StepData_ESDescr: ...
	def Field(self, num: int) -> StepData_PDescr: ...
	def IsComplex(self) -> bool: ...
	def IsSub(self, other: StepData_ESDescr) -> bool: ...
	def Matches(self, steptype: str) -> bool: ...
	def Name(self, num: int) -> str: ...
	def NamedField(self, name: str) -> StepData_PDescr: ...
	def NbFields(self) -> int: ...
	def NewEntity(self) -> StepData_Described: ...
	def Rank(self, name: str) -> int: ...
	def SetBase(self, base: StepData_ESDescr) -> None: ...
	def SetField(self, num: int, name: str, descr: StepData_PDescr) -> None: ...
	def SetNbFields(self, nb: int) -> None: ...
	def SetSuper(self, super: StepData_ESDescr) -> None: ...
	def StepType(self) -> TCollection_AsciiString: ...
	def Super(self) -> StepData_ESDescr: ...
	def TypeName(self) -> str: ...

class StepData_FieldList1(StepData_FieldList):
	def __init__(self) -> None: ...
	def CField(self, num: int) -> StepData_Field: ...
	def Field(self, num: int) -> StepData_Field: ...
	def NbFields(self) -> int: ...

class StepData_FieldListD(StepData_FieldList):
	def __init__(self, nb: int) -> None: ...
	def CField(self, num: int) -> StepData_Field: ...
	def Field(self, num: int) -> StepData_Field: ...
	def NbFields(self) -> int: ...
	def SetNb(self, nb: int) -> None: ...

class StepData_FieldListN(StepData_FieldList):
	def __init__(self, nb: int) -> None: ...
	def CField(self, num: int) -> StepData_Field: ...
	def Field(self, num: int) -> StepData_Field: ...
	def NbFields(self) -> int: ...

class StepData_FileProtocol(StepData_Protocol):
	def __init__(self) -> None: ...
	def Add(self, protocol: StepData_Protocol) -> None: ...
	def GlobalCheck(self, G: Interface_Graph, ach: Interface_Check) -> bool: ...
	def NbResources(self) -> int: ...
	def Resource(self, num: int) -> Interface_Protocol: ...
	def SchemaName(self) -> str: ...
	def TypeNumber(self, atype: Standard_Type) -> int: ...

class StepData_Plex(StepData_Described):
	def __init__(self, descr: StepData_ECDescr) -> None: ...
	def Add(self, member: StepData_Simple) -> None: ...
	def As(self, steptype: str) -> StepData_Simple: ...
	def CField(self, name: str) -> StepData_Field: ...
	def Check(self, ach: Interface_Check) -> None: ...
	def ECDescr(self) -> StepData_ECDescr: ...
	def Field(self, name: str) -> StepData_Field: ...
	def HasField(self, name: str) -> bool: ...
	def IsComplex(self) -> bool: ...
	def Matches(self, steptype: str) -> bool: ...
	def Member(self, num: int) -> StepData_Simple: ...
	def NbMembers(self) -> int: ...
	def Shared(self, list: Interface_EntityIterator) -> None: ...
	def TypeList(self) -> TColStd_HSequenceOfAsciiString: ...

class StepData_SelectInt(StepData_SelectMember):
	def __init__(self) -> None: ...
	def Int(self) -> int: ...
	def Kind(self) -> int: ...
	def SetInt(self, val: int) -> None: ...
	def SetKind(self, kind: int) -> None: ...

class StepData_SelectNamed(StepData_SelectMember):
	def __init__(self) -> None: ...
	def CField(self) -> StepData_Field: ...
	def Field(self) -> StepData_Field: ...
	def HasName(self) -> bool: ...
	def Int(self) -> int: ...
	def Kind(self) -> int: ...
	def Name(self) -> str: ...
	def Real(self) -> float: ...
	def SetInt(self, val: int) -> None: ...
	def SetKind(self, kind: int) -> None: ...
	def SetName(self, name: str) -> bool: ...
	def SetReal(self, val: float) -> None: ...
	def SetString(self, val: str) -> None: ...
	def String(self) -> str: ...

class StepData_SelectReal(StepData_SelectMember):
	def __init__(self) -> None: ...
	def Kind(self) -> int: ...
	def Real(self) -> float: ...
	def SetReal(self, val: float) -> None: ...

class StepData_Simple(StepData_Described):
	def __init__(self, descr: StepData_ESDescr) -> None: ...
	def As(self, steptype: str) -> StepData_Simple: ...
	def CField(self, name: str) -> StepData_Field: ...
	def CFieldNum(self, num: int) -> StepData_Field: ...
	def CFields(self) -> StepData_FieldListN: ...
	def Check(self, ach: Interface_Check) -> None: ...
	def ESDescr(self) -> StepData_ESDescr: ...
	def Field(self, name: str) -> StepData_Field: ...
	def FieldNum(self, num: int) -> StepData_Field: ...
	def Fields(self) -> StepData_FieldListN: ...
	def HasField(self, name: str) -> bool: ...
	def IsComplex(self) -> bool: ...
	def Matches(self, steptype: str) -> bool: ...
	def NbFields(self) -> int: ...
	def Shared(self, list: Interface_EntityIterator) -> None: ...
	def StepType(self) -> str: ...

class StepData_SelectArrReal(StepData_SelectNamed):
	def __init__(self) -> None: ...
	def ArrReal(self) -> TColStd_HArray1OfReal: ...
	def Kind(self) -> int: ...
	def SetArrReal(self, arr: TColStd_HArray1OfReal) -> None: ...

#classnotwrapped
class StepData_FreeFormEntity: ...

#classnotwrapped
class StepData_UndefinedEntity: ...

# harray1 classes

class StepData_HArray1OfField(StepData_Array1OfField, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepData_Array1OfField: ...

# harray2 classes
# hsequence classes

stepdata_AddHeaderProtocol = stepdata.AddHeaderProtocol
stepdata_HeaderProtocol = stepdata.HeaderProtocol
stepdata_Init = stepdata.Init
stepdata_Protocol = stepdata.Protocol
StepData_WriterLib_SetGlobal = StepData_WriterLib.SetGlobal



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
AppParCurves module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_appparcurves.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _AppParCurves
else:
    import _AppParCurves

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _AppParCurves.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _AppParCurves.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AppParCurves.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AppParCurves.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _AppParCurves.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _AppParCurves.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _AppParCurves.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _AppParCurves.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _AppParCurves.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _AppParCurves.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AppParCurves.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _AppParCurves.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _AppParCurves.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AppParCurves.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AppParCurves.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AppParCurves.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _AppParCurves.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _AppParCurves:
_AppParCurves.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _AppParCurves.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.math
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.gp
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *

AppParCurves_NoConstraint = _AppParCurves.AppParCurves_NoConstraint
AppParCurves_PassPoint = _AppParCurves.AppParCurves_PassPoint
AppParCurves_TangencyPoint = _AppParCurves.AppParCurves_TangencyPoint
AppParCurves_CurvaturePoint = _AppParCurves.AppParCurves_CurvaturePoint


class AppParCurves_Constraint(IntEnum):
	AppParCurves_NoConstraint = 0
	AppParCurves_PassPoint = 1
	AppParCurves_TangencyPoint = 2
	AppParCurves_CurvaturePoint = 3
AppParCurves_NoConstraint = AppParCurves_Constraint.AppParCurves_NoConstraint
AppParCurves_PassPoint = AppParCurves_Constraint.AppParCurves_PassPoint
AppParCurves_TangencyPoint = AppParCurves_Constraint.AppParCurves_TangencyPoint
AppParCurves_CurvaturePoint = AppParCurves_Constraint.AppParCurves_CurvaturePoint


def Handle_AppParCurves_HArray1OfMultiCurve_Create() -> "opencascade::handle< AppParCurves_HArray1OfMultiCurve >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiCurve_Create()

def Handle_AppParCurves_HArray1OfMultiCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< AppParCurves_HArray1OfMultiCurve >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiCurve_DownCast(t)

def Handle_AppParCurves_HArray1OfMultiCurve_IsNull(t: "opencascade::handle< AppParCurves_HArray1OfMultiCurve > const &") -> "bool":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiCurve_IsNull(t)

def Handle_AppParCurves_HArray1OfConstraintCouple_Create() -> "opencascade::handle< AppParCurves_HArray1OfConstraintCouple >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfConstraintCouple_Create()

def Handle_AppParCurves_HArray1OfConstraintCouple_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< AppParCurves_HArray1OfConstraintCouple >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfConstraintCouple_DownCast(t)

def Handle_AppParCurves_HArray1OfConstraintCouple_IsNull(t: "opencascade::handle< AppParCurves_HArray1OfConstraintCouple > const &") -> "bool":
    return _AppParCurves.Handle_AppParCurves_HArray1OfConstraintCouple_IsNull(t)

def Handle_AppParCurves_HArray1OfMultiPoint_Create() -> "opencascade::handle< AppParCurves_HArray1OfMultiPoint >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiPoint_Create()

def Handle_AppParCurves_HArray1OfMultiPoint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< AppParCurves_HArray1OfMultiPoint >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiPoint_DownCast(t)

def Handle_AppParCurves_HArray1OfMultiPoint_IsNull(t: "opencascade::handle< AppParCurves_HArray1OfMultiPoint > const &") -> "bool":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiPoint_IsNull(t)

def Handle_AppParCurves_HArray1OfMultiBSpCurve_Create() -> "opencascade::handle< AppParCurves_HArray1OfMultiBSpCurve >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiBSpCurve_Create()

def Handle_AppParCurves_HArray1OfMultiBSpCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< AppParCurves_HArray1OfMultiBSpCurve >":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiBSpCurve_DownCast(t)

def Handle_AppParCurves_HArray1OfMultiBSpCurve_IsNull(t: "opencascade::handle< AppParCurves_HArray1OfMultiBSpCurve > const &") -> "bool":
    return _AppParCurves.Handle_AppParCurves_HArray1OfMultiBSpCurve_IsNull(t)
class AppParCurves_Array1OfConstraintCouple(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< AppParCurves_ConstraintCouple >::iterator":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_begin(self)

    def end(self) -> "NCollection_Array1< AppParCurves_ConstraintCouple >::iterator":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_end(self)

    def cbegin(self) -> "NCollection_Array1< AppParCurves_ConstraintCouple >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_cbegin(self)

    def cend(self) -> "NCollection_Array1< AppParCurves_ConstraintCouple >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_cend(self)

    def __init__(self, *args):
        _AppParCurves.AppParCurves_Array1OfConstraintCouple_swiginit(self, _AppParCurves.new_AppParCurves_Array1OfConstraintCouple(*args))

    def Init(self, theValue: "AppParCurves_ConstraintCouple") -> "void":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Size(self)

    def Length(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_IsAllocated(self)

    def Assign(self, theOther: "AppParCurves_Array1OfConstraintCouple") -> "NCollection_Array1< AppParCurves_ConstraintCouple > &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Assign(self, theOther)

    def Move(self, theOther: "AppParCurves_Array1OfConstraintCouple") -> "NCollection_Array1< AppParCurves_ConstraintCouple > &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< AppParCurves_ConstraintCouple > &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Set(self, *args)

    def First(self) -> "AppParCurves_ConstraintCouple const &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_First(self)

    def ChangeFirst(self) -> "AppParCurves_ConstraintCouple &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_ChangeFirst(self)

    def Last(self) -> "AppParCurves_ConstraintCouple const &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Last(self)

    def ChangeLast(self) -> "AppParCurves_ConstraintCouple &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "AppParCurves_ConstraintCouple const &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "AppParCurves_ConstraintCouple &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "AppParCurves_ConstraintCouple &":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "AppParCurves_ConstraintCouple") -> "void":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _AppParCurves.AppParCurves_Array1OfConstraintCouple_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _AppParCurves.delete_AppParCurves_Array1OfConstraintCouple

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register AppParCurves_Array1OfConstraintCouple in _AppParCurves:
_AppParCurves.AppParCurves_Array1OfConstraintCouple_swigregister(AppParCurves_Array1OfConstraintCouple)

class AppParCurves_Array1OfMultiBSpCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< AppParCurves_MultiBSpCurve >::iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_begin(self)

    def end(self) -> "NCollection_Array1< AppParCurves_MultiBSpCurve >::iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< AppParCurves_MultiBSpCurve >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< AppParCurves_MultiBSpCurve >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_cend(self)

    def __init__(self, *args):
        _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_swiginit(self, _AppParCurves.new_AppParCurves_Array1OfMultiBSpCurve(*args))

    def Init(self, theValue: "AppParCurves_MultiBSpCurve") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_IsAllocated(self)

    def Assign(self, theOther: "AppParCurves_Array1OfMultiBSpCurve") -> "NCollection_Array1< AppParCurves_MultiBSpCurve > &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Assign(self, theOther)

    def Move(self, theOther: "AppParCurves_Array1OfMultiBSpCurve") -> "NCollection_Array1< AppParCurves_MultiBSpCurve > &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< AppParCurves_MultiBSpCurve > &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Set(self, *args)

    def First(self) -> "AppParCurves_MultiBSpCurve const &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_First(self)

    def ChangeFirst(self) -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_ChangeFirst(self)

    def Last(self) -> "AppParCurves_MultiBSpCurve const &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Last(self)

    def ChangeLast(self) -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiBSpCurve const &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "AppParCurves_MultiBSpCurve") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiBSpCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _AppParCurves.delete_AppParCurves_Array1OfMultiBSpCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register AppParCurves_Array1OfMultiBSpCurve in _AppParCurves:
_AppParCurves.AppParCurves_Array1OfMultiBSpCurve_swigregister(AppParCurves_Array1OfMultiBSpCurve)

class AppParCurves_Array1OfMultiCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< AppParCurves_MultiCurve >::iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_begin(self)

    def end(self) -> "NCollection_Array1< AppParCurves_MultiCurve >::iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< AppParCurves_MultiCurve >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< AppParCurves_MultiCurve >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_cend(self)

    def __init__(self, *args):
        _AppParCurves.AppParCurves_Array1OfMultiCurve_swiginit(self, _AppParCurves.new_AppParCurves_Array1OfMultiCurve(*args))

    def Init(self, theValue: "AppParCurves_MultiCurve") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_IsAllocated(self)

    def Assign(self, theOther: "AppParCurves_Array1OfMultiCurve") -> "NCollection_Array1< AppParCurves_MultiCurve > &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Assign(self, theOther)

    def Move(self, theOther: "AppParCurves_Array1OfMultiCurve") -> "NCollection_Array1< AppParCurves_MultiCurve > &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< AppParCurves_MultiCurve > &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Set(self, *args)

    def First(self) -> "AppParCurves_MultiCurve const &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_First(self)

    def ChangeFirst(self) -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_ChangeFirst(self)

    def Last(self) -> "AppParCurves_MultiCurve const &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Last(self)

    def ChangeLast(self) -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiCurve const &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "AppParCurves_MultiCurve") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _AppParCurves.delete_AppParCurves_Array1OfMultiCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register AppParCurves_Array1OfMultiCurve in _AppParCurves:
_AppParCurves.AppParCurves_Array1OfMultiCurve_swigregister(AppParCurves_Array1OfMultiCurve)

class AppParCurves_Array1OfMultiPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< AppParCurves_MultiPoint >::iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_begin(self)

    def end(self) -> "NCollection_Array1< AppParCurves_MultiPoint >::iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_end(self)

    def cbegin(self) -> "NCollection_Array1< AppParCurves_MultiPoint >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_cbegin(self)

    def cend(self) -> "NCollection_Array1< AppParCurves_MultiPoint >::const_iterator":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_cend(self)

    def __init__(self, *args):
        _AppParCurves.AppParCurves_Array1OfMultiPoint_swiginit(self, _AppParCurves.new_AppParCurves_Array1OfMultiPoint(*args))

    def Init(self, theValue: "AppParCurves_MultiPoint") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_IsAllocated(self)

    def Assign(self, theOther: "AppParCurves_Array1OfMultiPoint") -> "NCollection_Array1< AppParCurves_MultiPoint > &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Assign(self, theOther)

    def Move(self, theOther: "AppParCurves_Array1OfMultiPoint") -> "NCollection_Array1< AppParCurves_MultiPoint > &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< AppParCurves_MultiPoint > &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Set(self, *args)

    def First(self) -> "AppParCurves_MultiPoint const &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_First(self)

    def ChangeFirst(self) -> "AppParCurves_MultiPoint &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_ChangeFirst(self)

    def Last(self) -> "AppParCurves_MultiPoint const &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Last(self)

    def ChangeLast(self) -> "AppParCurves_MultiPoint &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiPoint const &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiPoint &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "AppParCurves_MultiPoint &":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "AppParCurves_MultiPoint") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _AppParCurves.AppParCurves_Array1OfMultiPoint_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _AppParCurves.delete_AppParCurves_Array1OfMultiPoint

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register AppParCurves_Array1OfMultiPoint in _AppParCurves:
_AppParCurves.AppParCurves_Array1OfMultiPoint_swigregister(AppParCurves_Array1OfMultiPoint)

class AppParCurves_SequenceOfMultiBSpCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< AppParCurves_MultiBSpCurve >::iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_begin(self)

    def end(self) -> "NCollection_Sequence< AppParCurves_MultiBSpCurve >::iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< AppParCurves_MultiBSpCurve >::const_iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< AppParCurves_MultiBSpCurve >::const_iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_cend(self)

    def __init__(self, *args):
        _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_swiginit(self, _AppParCurves.new_AppParCurves_SequenceOfMultiBSpCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "AppParCurves_SequenceOfMultiBSpCurve") -> "NCollection_Sequence< AppParCurves_MultiBSpCurve > &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Assign(self, theOther)

    def Set(self, theOther: "AppParCurves_SequenceOfMultiBSpCurve") -> "NCollection_Sequence< AppParCurves_MultiBSpCurve > &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "AppParCurves_SequenceOfMultiBSpCurve") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Split(self, theIndex, theSeq)

    def First(self) -> "AppParCurves_MultiBSpCurve const &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_First(self)

    def ChangeFirst(self) -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_ChangeFirst(self)

    def Last(self) -> "AppParCurves_MultiBSpCurve const &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Last(self)

    def ChangeLast(self) -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiBSpCurve const &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "AppParCurves_MultiBSpCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "AppParCurves_MultiBSpCurve") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _AppParCurves.delete_AppParCurves_SequenceOfMultiBSpCurve

    def __len__(self):
        return self.Size()


# Register AppParCurves_SequenceOfMultiBSpCurve in _AppParCurves:
_AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_swigregister(AppParCurves_SequenceOfMultiBSpCurve)

def AppParCurves_SequenceOfMultiBSpCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _AppParCurves.AppParCurves_SequenceOfMultiBSpCurve_delNode(theNode, theAl)

class AppParCurves_SequenceOfMultiCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< AppParCurves_MultiCurve >::iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_begin(self)

    def end(self) -> "NCollection_Sequence< AppParCurves_MultiCurve >::iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< AppParCurves_MultiCurve >::const_iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< AppParCurves_MultiCurve >::const_iterator":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_cend(self)

    def __init__(self, *args):
        _AppParCurves.AppParCurves_SequenceOfMultiCurve_swiginit(self, _AppParCurves.new_AppParCurves_SequenceOfMultiCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "AppParCurves_SequenceOfMultiCurve") -> "NCollection_Sequence< AppParCurves_MultiCurve > &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Assign(self, theOther)

    def Set(self, theOther: "AppParCurves_SequenceOfMultiCurve") -> "NCollection_Sequence< AppParCurves_MultiCurve > &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "AppParCurves_SequenceOfMultiCurve") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Split(self, theIndex, theSeq)

    def First(self) -> "AppParCurves_MultiCurve const &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_First(self)

    def ChangeFirst(self) -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_ChangeFirst(self)

    def Last(self) -> "AppParCurves_MultiCurve const &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Last(self)

    def ChangeLast(self) -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiCurve const &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "AppParCurves_MultiCurve &":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "AppParCurves_MultiCurve") -> "void":
        return _AppParCurves.AppParCurves_SequenceOfMultiCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _AppParCurves.delete_AppParCurves_SequenceOfMultiCurve

    def __len__(self):
        return self.Size()


# Register AppParCurves_SequenceOfMultiCurve in _AppParCurves:
_AppParCurves.AppParCurves_SequenceOfMultiCurve_swigregister(AppParCurves_SequenceOfMultiCurve)

def AppParCurves_SequenceOfMultiCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _AppParCurves.AppParCurves_SequenceOfMultiCurve_delNode(theNode, theAl)

class appparcurves(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Bernstein(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        NbPoles: int
        U: math_Vector
        A: math_Matrix
        DA: math_Matrix

        Returns
        -------
        None

        """
        return _AppParCurves.appparcurves_Bernstein(*args)

    @staticmethod
    def BernsteinMatrix(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        NbPoles: int
        U: math_Vector
        A: math_Matrix

        Returns
        -------
        None

        """
        return _AppParCurves.appparcurves_BernsteinMatrix(*args)

    @staticmethod
    def SecondDerivativeBernstein(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        DDA: math_Vector

        Returns
        -------
        None

        """
        return _AppParCurves.appparcurves_SecondDerivativeBernstein(*args)

    @staticmethod
    def SplineFunction(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        NbPoles: int
        Degree: int
        Parameters: math_Vector
        FlatKnots: math_Vector
        A: math_Matrix
        DA: math_Matrix
        Index: math_IntegerVector

        Returns
        -------
        None

        """
        return _AppParCurves.appparcurves_SplineFunction(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _AppParCurves.appparcurves_swiginit(self, _AppParCurves.new_appparcurves())
    __swig_destroy__ = _AppParCurves.delete_appparcurves

# Register appparcurves in _AppParCurves:
_AppParCurves.appparcurves_swigregister(appparcurves)

def appparcurves_Bernstein(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    NbPoles: int
    U: math_Vector
    A: math_Matrix
    DA: math_Matrix

    Returns
    -------
    None

    """
    return _AppParCurves.appparcurves_Bernstein(*args)

def appparcurves_BernsteinMatrix(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    NbPoles: int
    U: math_Vector
    A: math_Matrix

    Returns
    -------
    None

    """
    return _AppParCurves.appparcurves_BernsteinMatrix(*args)

def appparcurves_SecondDerivativeBernstein(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    DDA: math_Vector

    Returns
    -------
    None

    """
    return _AppParCurves.appparcurves_SecondDerivativeBernstein(*args)

def appparcurves_SplineFunction(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    NbPoles: int
    Degree: int
    Parameters: math_Vector
    FlatKnots: math_Vector
    A: math_Matrix
    DA: math_Matrix
    Index: math_IntegerVector

    Returns
    -------
    None

    """
    return _AppParCurves.appparcurves_SplineFunction(*args)

class AppParCurves_ConstraintCouple(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns an indefinite constraintcouple.

        Returns
        -------
        None
        Create a couple the object <index> will have the constraint <cons>.

        Parameters
        ----------
        TheIndex: int
        Cons: AppParCurves_Constraint

        Returns
        -------
        None

        """
        _AppParCurves.AppParCurves_ConstraintCouple_swiginit(self, _AppParCurves.new_AppParCurves_ConstraintCouple(*args))

    def Constraint(self, *args) -> "AppParCurves_Constraint":
        r"""
        Returns the constraint of the object.

        Returns
        -------
        AppParCurves_Constraint

        """
        return _AppParCurves.AppParCurves_ConstraintCouple_Constraint(self, *args)

    def Index(self, *args) -> "Standard_Integer":
        r"""
        Returns the index of the constraint object.

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_ConstraintCouple_Index(self, *args)

    def SetConstraint(self, *args) -> "void":
        r"""
        Changes the constraint of the object.

        Parameters
        ----------
        Cons: AppParCurves_Constraint

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_ConstraintCouple_SetConstraint(self, *args)

    def SetIndex(self, *args) -> "void":
        r"""
        Changes the index of the constraint object.

        Parameters
        ----------
        TheIndex: int

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_ConstraintCouple_SetIndex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_ConstraintCouple

# Register AppParCurves_ConstraintCouple in _AppParCurves:
_AppParCurves.AppParCurves_ConstraintCouple_swigregister(AppParCurves_ConstraintCouple)

class AppParCurves_MultiCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns an indefinite multicurve.

        Returns
        -------
        None
        Creates a multicurve, describing bezier curves all containing the same number of multipoint. an exception is raised if degree < 0.

        Parameters
        ----------
        NbPol: int

        Returns
        -------
        None
        Creates a multicurve, describing bezier curves all containing the same number of multipoint. each multipoint must have nbcurves poles.

        Parameters
        ----------
        tabMU: AppParCurves_Array1OfMultiPoint

        Returns
        -------
        None

        """
        _AppParCurves.AppParCurves_MultiCurve_swiginit(self, _AppParCurves.new_AppParCurves_MultiCurve(*args))

    def Curve(self, *args) -> "void":
        r"""
        Returns the pole array of the curve of range cuindex. an exception is raised if the dimension of the curve is 2d.

        Parameters
        ----------
        CuIndex: int
        TabPnt: TColgp_Array1OfPnt

        Returns
        -------
        None
        Returns the pole array of the curve of range cuindex. an exception is raised if the dimension of the curve is 3d.

        Parameters
        ----------
        CuIndex: int
        TabPnt: TColgp_Array1OfPnt2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_Curve(self, *args)

    def D1(self, *args) -> "void":
        r"""
        Returns the value of the point with a parameter u on the bezier curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 3d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt
        V1: gp_Vec

        Returns
        -------
        None
        Returns the value of the point with a parameter u on the bezier curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 2d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt2d
        V1: gp_Vec2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Returns the value of the point with a parameter u on the bezier curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 3d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt
        V1: gp_Vec
        V2: gp_Vec

        Returns
        -------
        None
        Returns the value of the point with a parameter u on the bezier curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 2d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_D2(self, *args)

    def Degree(self, *args) -> "Standard_Integer":
        r"""
        Returns the degree of the curves.

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_MultiCurve_Degree(self, *args)

    def Dimension(self, *args) -> "Standard_Integer":
        r"""
        Returns the dimension of the cuindex curve. an exception is raised if cuindex<0 or cuindex>nbcurves.

        Parameters
        ----------
        CuIndex: int

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_MultiCurve_Dimension(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(AppParCurves_MultiCurve self) -> std::string"""
        return _AppParCurves.AppParCurves_MultiCurve_DumpToString(self)

    def NbCurves(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of curves resulting from the approximation of a multiline.

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_MultiCurve_NbCurves(self, *args)

    def NbPoles(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of poles on curves resulting from the approximation of a multiline.

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_MultiCurve_NbPoles(self, *args)

    def Pole(self, *args) -> "gp_Pnt const":
        r"""
        Returns the nieme pole of the cuindex curve. the curve must be a 3d curve.

        Parameters
        ----------
        CuIndex: int
        Nieme: int

        Returns
        -------
        gp_Pnt

        """
        return _AppParCurves.AppParCurves_MultiCurve_Pole(self, *args)

    def Pole2d(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the nieme pole of the cuindex curve. the curve must be a 2d curve.

        Parameters
        ----------
        CuIndex: int
        Nieme: int

        Returns
        -------
        gp_Pnt2d

        """
        return _AppParCurves.AppParCurves_MultiCurve_Pole2d(self, *args)

    def SetNbPoles(self, *args) -> "void":
        r"""
        The number of poles of the multicurve will be set to <nbpoles>.

        Parameters
        ----------
        nbPoles: int

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_SetNbPoles(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Sets the multipoint of range index to the value <mpoint>. an exception is raised if index <0 or index >nbmpoint.

        Parameters
        ----------
        Index: int
        MPoint: AppParCurves_MultiPoint

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_SetValue(self, *args)

    def Transform(self, *args) -> "void":
        r"""
        Applies a transformation to the curve of range <cuindex>. newx = x + dx*oldx newy = y + dy*oldy for all points of the curve. newz = z + dz*oldz.

        Parameters
        ----------
        CuIndex: int
        x: float
        dx: float
        y: float
        dy: float
        z: float
        dz: float

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_Transform(self, *args)

    def Transform2d(self, *args) -> "void":
        r"""
        Applies a transformation to the curve of range <cuindex>. newx = x + dx*oldx newy = y + dy*oldy for all points of the curve.

        Parameters
        ----------
        CuIndex: int
        x: float
        dx: float
        y: float
        dy: float

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_Transform2d(self, *args)

    def Value(self, *args) -> "void":
        r"""
        Returns the index multipoint. an exception is raised if index <0 or index >degree+1.

        Parameters
        ----------
        Index: int

        Returns
        -------
        AppParCurves_MultiPoint
        Returns the value of the point with a parameter u on the bezier curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 2d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt

        Returns
        -------
        None
        Returns the value of the point with a parameter u on the bezier curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 3d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiCurve_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_MultiCurve

# Register AppParCurves_MultiCurve in _AppParCurves:
_AppParCurves.AppParCurves_MultiCurve_swigregister(AppParCurves_MultiCurve)

class AppParCurves_MultiPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an indefinite multipoint.

        Returns
        -------
        None
        Constructs a set of points used to approximate a multiline. these points can be of 2 or 3 dimensions. points will be initialized with setpoint and setpoint2d. nbpoints is the number of 3d points. nbpoints2d is the number of 2d points.

        Parameters
        ----------
        NbPoints: int
        NbPoints2d: int

        Returns
        -------
        None
        Creates a multipoint only composed of 3d points.

        Parameters
        ----------
        tabP: TColgp_Array1OfPnt

        Returns
        -------
        None
        Creates a multipoint only composed of 2d points.

        Parameters
        ----------
        tabP2d: TColgp_Array1OfPnt2d

        Returns
        -------
        None
        Constructs a set of points used to approximate a multiline. these points can be of 2 or 3 dimensions. points will be initialized with setpoint and setpoint2d. nbpoints is the total number of points.

        Parameters
        ----------
        tabP: TColgp_Array1OfPnt
        tabP2d: TColgp_Array1OfPnt2d

        Returns
        -------
        None

        """
        _AppParCurves.AppParCurves_MultiPoint_swiginit(self, _AppParCurves.new_AppParCurves_MultiPoint(*args))

    def Dimension(self, *args) -> "Standard_Integer":
        r"""
        Returns the dimension of the point of range index. an exception is raised if index <0 or index > nbcurves.

        Parameters
        ----------
        Index: int

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_MultiPoint_Dimension(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(AppParCurves_MultiPoint self) -> std::string"""
        return _AppParCurves.AppParCurves_MultiPoint_DumpToString(self)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of points of dimension 3d.

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_MultiPoint_NbPoints(self, *args)

    def NbPoints2d(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of points of dimension 2d.

        Returns
        -------
        int

        """
        return _AppParCurves.AppParCurves_MultiPoint_NbPoints2d(self, *args)

    def Point(self, *args) -> "gp_Pnt const":
        r"""
        Returns the 3d point of range index. an exception is raised if index < 0 or index < number of 3d points.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt

        """
        return _AppParCurves.AppParCurves_MultiPoint_Point(self, *args)

    def Point2d(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the 2d point of range index. an exception is raised if index <= number of 3d points or index > total number of points.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt2d

        """
        return _AppParCurves.AppParCurves_MultiPoint_Point2d(self, *args)

    def SetPoint(self, *args) -> "void":
        r"""
        The 3d point of range index of this multipoint is set to <point>. an exception is raised if index < 0 or index > number of 3d points.

        Parameters
        ----------
        Index: int
        Point: gp_Pnt

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiPoint_SetPoint(self, *args)

    def SetPoint2d(self, *args) -> "void":
        r"""
        The 2d point of range index is set to <point>. an exception is raised if index > 3d points or index > total number of points.

        Parameters
        ----------
        Index: int
        Point: gp_Pnt2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiPoint_SetPoint2d(self, *args)

    def Transform(self, *args) -> "void":
        r"""
        Applies a transformation to the curve of range <cuindex>. newx = x + dx*oldx newy = y + dy*oldy for all points of the curve. newz = z + dz*oldz.

        Parameters
        ----------
        CuIndex: int
        x: float
        dx: float
        y: float
        dy: float
        z: float
        dz: float

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiPoint_Transform(self, *args)

    def Transform2d(self, *args) -> "void":
        r"""
        Applies a transformation to the curve of range <cuindex>. newx = x + dx*oldx newy = y + dy*oldy for all points of the curve.

        Parameters
        ----------
        CuIndex: int
        x: float
        dx: float
        y: float
        dy: float

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiPoint_Transform2d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_MultiPoint

# Register AppParCurves_MultiPoint in _AppParCurves:
_AppParCurves.AppParCurves_MultiPoint_swigregister(AppParCurves_MultiPoint)

class AppParCurves_MultiBSpCurve(AppParCurves_MultiCurve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns an indefinite multibspcurve.

        Returns
        -------
        None
        Creates a multibspcurve, describing bspline curves all containing the same number of multipoint. an exception is raised if degree < 0.

        Parameters
        ----------
        NbPol: int

        Returns
        -------
        None
        Creates a multibspcurve, describing bspline curves all containing the same number of multipoint. each multipoint must have nbcurves poles.

        Parameters
        ----------
        tabMU: AppParCurves_Array1OfMultiPoint
        Knots: TColStd_Array1OfReal
        Mults: TColStd_Array1OfInteger

        Returns
        -------
        None
        Creates a multibspcurve, describing bspline curves, taking control points from <sc>.

        Parameters
        ----------
        SC: AppParCurves_MultiCurve
        Knots: TColStd_Array1OfReal
        Mults: TColStd_Array1OfInteger

        Returns
        -------
        None

        """
        _AppParCurves.AppParCurves_MultiBSpCurve_swiginit(self, _AppParCurves.new_AppParCurves_MultiBSpCurve(*args))

    def D1(self, *args) -> "void":
        r"""
        Returns the value of the point with a parameter u on the bspline curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 3d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt
        V1: gp_Vec

        Returns
        -------
        None
        Returns the value of the point with a parameter u on the bspline curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 2d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt2d
        V1: gp_Vec2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiBSpCurve_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Returns the value of the point with a parameter u on the bspline curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 3d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt
        V1: gp_Vec
        V2: gp_Vec

        Returns
        -------
        None
        Returns the value of the point with a parameter u on the bspline curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 2d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiBSpCurve_D2(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(AppParCurves_MultiBSpCurve self) -> std::string"""
        return _AppParCurves.AppParCurves_MultiBSpCurve_DumpToString(self)

    def Knots(self, *args) -> "TColStd_Array1OfReal const &":
        r"""
        Returns an array of reals containing the multiplicities of curves resulting from the approximation.

        Returns
        -------
        TColStd_Array1OfReal

        """
        return _AppParCurves.AppParCurves_MultiBSpCurve_Knots(self, *args)

    def Multiplicities(self, *args) -> "TColStd_Array1OfInteger const &":
        r"""
        Returns an array of reals containing the multiplicities of curves resulting from the approximation.

        Returns
        -------
        TColStd_Array1OfInteger

        """
        return _AppParCurves.AppParCurves_MultiBSpCurve_Multiplicities(self, *args)

    def SetKnots(self, *args) -> "void":
        r"""
        Knots of the multibspcurve are assigned to <theknots>.

        Parameters
        ----------
        theKnots: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiBSpCurve_SetKnots(self, *args)

    def SetMultiplicities(self, *args) -> "void":
        r"""
        Multiplicities of the multibspcurve are assigned to <themults>.

        Parameters
        ----------
        theMults: TColStd_Array1OfInteger

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiBSpCurve_SetMultiplicities(self, *args)

    def Value(self, *args) -> "void":
        r"""
        Returns the value of the point with a parameter u on the bspline curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 2d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt

        Returns
        -------
        None
        Returns the value of the point with a parameter u on the bspline curve number cuindex. an exception is raised if cuindex <0 or > nbcurves. an exception is raised if the curve dimension is 3d.

        Parameters
        ----------
        CuIndex: int
        U: float
        Pt: gp_Pnt2d

        Returns
        -------
        None

        """
        return _AppParCurves.AppParCurves_MultiBSpCurve_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_MultiBSpCurve

# Register AppParCurves_MultiBSpCurve in _AppParCurves:
_AppParCurves.AppParCurves_MultiBSpCurve_swigregister(AppParCurves_MultiBSpCurve)

class AppParCurves_HArray1OfMultiCurve(AppParCurves_Array1OfMultiCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _AppParCurves.AppParCurves_HArray1OfMultiCurve_swiginit(self, _AppParCurves.new_AppParCurves_HArray1OfMultiCurve(*args))

    def Array1(self) -> "AppParCurves_Array1OfMultiCurve const &":
        return _AppParCurves.AppParCurves_HArray1OfMultiCurve_Array1(self)

    def ChangeArray1(self) -> "AppParCurves_Array1OfMultiCurve &":
        return _AppParCurves.AppParCurves_HArray1OfMultiCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_AppParCurves_HArray1OfMultiCurve_DownCast(t)

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_HArray1OfMultiCurve

# Register AppParCurves_HArray1OfMultiCurve in _AppParCurves:
_AppParCurves.AppParCurves_HArray1OfMultiCurve_swigregister(AppParCurves_HArray1OfMultiCurve)

class AppParCurves_HArray1OfConstraintCouple(AppParCurves_Array1OfConstraintCouple, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _AppParCurves.AppParCurves_HArray1OfConstraintCouple_swiginit(self, _AppParCurves.new_AppParCurves_HArray1OfConstraintCouple(*args))

    def Array1(self) -> "AppParCurves_Array1OfConstraintCouple const &":
        return _AppParCurves.AppParCurves_HArray1OfConstraintCouple_Array1(self)

    def ChangeArray1(self) -> "AppParCurves_Array1OfConstraintCouple &":
        return _AppParCurves.AppParCurves_HArray1OfConstraintCouple_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_AppParCurves_HArray1OfConstraintCouple_DownCast(t)

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_HArray1OfConstraintCouple

# Register AppParCurves_HArray1OfConstraintCouple in _AppParCurves:
_AppParCurves.AppParCurves_HArray1OfConstraintCouple_swigregister(AppParCurves_HArray1OfConstraintCouple)

class AppParCurves_HArray1OfMultiPoint(AppParCurves_Array1OfMultiPoint, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _AppParCurves.AppParCurves_HArray1OfMultiPoint_swiginit(self, _AppParCurves.new_AppParCurves_HArray1OfMultiPoint(*args))

    def Array1(self) -> "AppParCurves_Array1OfMultiPoint const &":
        return _AppParCurves.AppParCurves_HArray1OfMultiPoint_Array1(self)

    def ChangeArray1(self) -> "AppParCurves_Array1OfMultiPoint &":
        return _AppParCurves.AppParCurves_HArray1OfMultiPoint_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_AppParCurves_HArray1OfMultiPoint_DownCast(t)

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_HArray1OfMultiPoint

# Register AppParCurves_HArray1OfMultiPoint in _AppParCurves:
_AppParCurves.AppParCurves_HArray1OfMultiPoint_swigregister(AppParCurves_HArray1OfMultiPoint)

class AppParCurves_HArray1OfMultiBSpCurve(AppParCurves_Array1OfMultiBSpCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _AppParCurves.AppParCurves_HArray1OfMultiBSpCurve_swiginit(self, _AppParCurves.new_AppParCurves_HArray1OfMultiBSpCurve(*args))

    def Array1(self) -> "AppParCurves_Array1OfMultiBSpCurve const &":
        return _AppParCurves.AppParCurves_HArray1OfMultiBSpCurve_Array1(self)

    def ChangeArray1(self) -> "AppParCurves_Array1OfMultiBSpCurve &":
        return _AppParCurves.AppParCurves_HArray1OfMultiBSpCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_AppParCurves_HArray1OfMultiBSpCurve_DownCast(t)

    __swig_destroy__ = _AppParCurves.delete_AppParCurves_HArray1OfMultiBSpCurve

# Register AppParCurves_HArray1OfMultiBSpCurve in _AppParCurves:
_AppParCurves.AppParCurves_HArray1OfMultiBSpCurve_swigregister(AppParCurves_HArray1OfMultiBSpCurve)





